Skip to contents

Combined plot of a time Series and its autocorrelation and partial autocorrelation

Usage

plotTimeSeries(
  x,
  maxLag = 10 * log10(length(x)),
  ylab = NULL,
  main = NULL,
  ...
)

Arguments

x

univariate time series.

maxLag

integer. Defines the number of lags to be displayed. The default is 10 * log10(length(series)).

ylab

a title for the y axis: see title().

main

an overall title for the plot

...

the dots are passed to the plot command.

Details

plotTimeSeries plots a combination of the time series and its autocorrelation and partial autocorrelation.

Note

Rewritten based on ideas of M.Huerzeler

Examples


plotTimeSeries(AirPassengers)