This is just a wrapper for creating an empty plot with suitable defaults for plotting geometric shapes.
Arguments
- xlim, ylim
the xlims and ylims for the plot. Default is c(-1, 1).
- main
the main title on top of the plot.
- asp
numeric, giving the aspect ratio y/x. (See
plot.window()for details. Default is 1.- usrbg
the color of the user space of the plot, defaults to "white".
- ...
additional arguments are passed to the
plot()command.
Details
The plot is created with these settings:asp = 1, xaxt = "n", yaxt = "n", xlab = "", ylab = "", frame.plot = FALSE.
See also
Other graphics.setup:
polarGrid(),
setBackCol()
Examples
canvas(7)
text(0, 0, "Hello world!", cex=5)