Convert Degrees to Radians and Vice Versa
Source:R/degree-radians-conversion.R
degree-radians-conversion.RdConvert degrees to radians (and back again).
Value
degToRad returns a vector of the same length as deg with the
angles in radians.
radToDeg returns a vector of the same length as
rad with the angles in degrees.
See also
Other geometry.conversion:
coordinate-conversions