Takes a data frame and displays the location of missing data. The missings can be clustered and be displayed together.
Usage
plotMiss(
x,
col = "deeppink4",
bg = fade("navajowhite3", 0.3),
clust = FALSE,
main = NULL,
...
)Arguments
- x
a data.frame to be analysed.
- col
the colour of the missings.
- bg
the background colour of the plot.
- clust
logical, defining if the missings should be clustered. Default is
FALSE.- main
the main title.
- ...
the dots are passed to
plot().
Details
A graphical display of the position of the missings can be help to detect dependencies or patterns within the missings.
Note
Following an idea of Henk Harmsen henk@carbonmetrics.com
See also
hclust(), bedrock::countCompCases()
Other plot.special:
plotBinaryTree(),
plotCirc(),
plotLift(),
plotPolar(),
plotPropCI(),
plotTernary(),
plotTimeSeries(),
plotTreemap(),
plotWeb()