Combined plot of a time Series and its autocorrelation and partial autocorrelation
Arguments
- x
univariate time series.
- maxLag
integer. Defines the number of lags to be displayed. The default is 10 * log10(length(series)).
- ylab
a title for the y axis: see
title().- main
an overall title for the plot
- ...
the dots are passed to the plot command.
Details
plotTimeSeries plots a combination of the time series and its autocorrelation and partial autocorrelation.
See also
Other plot.special:
plotBinaryTree(),
plotCirc(),
plotLift(),
plotMiss(),
plotPolar(),
plotPropCI(),
plotTernary(),
plotTreemap(),
plotWeb()