strPad will fill a string x with defined characters to fit a given
length.
Arguments
- x
a vector of strings to be padded
- width
resulting width of padded string. If x is a vector and width is left to NULL, it will be set to the length of the largest string in x.
- pad
string to pad with. Will be repeated as often as necessary. Default is " ".
- adj
adjustment of the old string, one of
"left","right","center". If set to"left"the old string will be adjusted on the left and the new characters will be filled in on the right side.
See also
string-overview for an overview of all string utilities in pharos.